PhoneNumber class
Represents a phone number associated with a SIM slot.
Constructors
- PhoneNumber({required int simSlot, required String phoneNumber})
-
Creates a PhoneNumber instance.
const
-
PhoneNumber.fromMap(Map<
String, dynamic> map) -
Creates a PhoneNumber from a Map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- phoneNumber → String
-
The phone number associated with the SIM card.
May be empty if the carrier does not store it on the SIM.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simSlot → int
-
The SIM slot index (0-based).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited