SimCard class
Represents a SIM card installed on the device.
Constructors
Properties
- carrierName → String
-
The carrier name (e.g., "Telkomsel", "XL").
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iccId → String
-
The ICC ID of the SIM card.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simSlot → int
-
The SIM slot index (0-based).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts this SimCard to a Map.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited