SmsSenderPlatform class abstract
The interface that defines platform-specific implementations of SmsSender.
- Inheritance
-
- Object
- PlatformInterface
- SmsSenderPlatform
- Implementers
Constructors
- SmsSenderPlatform()
- Constructs a SmsSenderPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPhoneNumbers(
) → Future< List< PhoneNumber> > -
Retrieves phone numbers for each SIM slot.
Requires
READ_PHONE_NUMBERSpermission on Android 11+. -
getSimCards(
) → Future< List< SimCard> > - Retrieves a list of available SIM cards on the device.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendSms(
String phoneNumber, String message, int simSlot) → Future< String> -
Sends an SMS message to the specified
phoneNumber. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ SmsSenderPlatform
-
The default instance of SmsSenderPlatform.
getter/setter pair